@@ -19,25 +19,39 @@
 #include "biometricauthwidget.h"
 #include <QLabel>
 #include <QDebug>
+#include <QDBusUnixFileDescriptor>
+#include <unistd.h>
 #include <pwd.h>
 
+#include <opencv2/core/core.hpp>
+#include <opencv2/imgproc/imgproc.hpp>
+#include <opencv2/highgui/highgui.hpp>
+#include <opencv2/opencv.hpp>
+
+#include "giodbus.h"
+
 BiometricAuthWidget::BiometricAuthWidget(BiometricProxy *proxy, QWidget *parent) :
     QWidget(parent),
     proxy(proxy),
     isInAuth(false),
-    movieTimer(nullptr),
-    retrytimer(nullptr),
+    movieTimer(nullptr), 
     failedCount(0),
     timeoutCount(0),
-    beStopped(false)
+    beStopped(false),
+    retrytimer(nullptr),
+    usebind(false)
 {
+    usebind = getAuthDouble();
     initUI();
-    resize(400, 200);
+    resize(400, 260);
 
     if(this->proxy)
     {
         connect(this->proxy, &BiometricProxy::StatusChanged,
                 this, &BiometricAuthWidget::onStatusChanged);
+
+        connect(this->proxy, &BiometricProxy::FrameWritten,
+                this, &BiometricAuthWidget::onFrameWritten);
     }
 
 }
@@ -57,16 +71,18 @@ void BiometricAuthWidget::initUI()
     //显示图片
     lblImage = new QLabel(this);
     lblImage->setFixedSize(100, 100);
+
 }
 
 
 void BiometricAuthWidget::resizeEvent(QResizeEvent */*event*/)
 {
-    lblNotify->setGeometry(0, 0, width(), 40);
+    lblNotify->setGeometry(0, 0, width(), 45);
     lblDevice->setGeometry(0, lblNotify->geometry().bottom()+5, width(), 30);
     lblImage->setGeometry((width() - lblImage->width()) / 2,
                            lblDevice->geometry().bottom() + 10,
                            lblImage->width(), lblImage->height());
+    //qDebug()
 }
 
 void BiometricAuthWidget::startAuth(DeviceInfoPtr device, int uid)
@@ -89,25 +105,29 @@ void BiometricAuthWidget::startAuth(DeviceInfoPtr device, int uid)
     this->failedCount = 0;
     this->timeoutCount = 0;
     this->beStopped = false;
-	
     proxy->StopOps(device->id);
     startAuth_();
+
+    if(device->deviceType != DeviceType::Type::Face){
+        updateImage(1);
+    }
+
 }
 
 void BiometricAuthWidget::startAuth_()
 {
     lblDevice->setText(tr("Current device: ") + device->shortName);
 
-    qDebug().noquote() << QString("Identify:[drvid: %1, uid: %2]").arg(1).arg(2);
+    //qDebug().noquote() << QString("Identify:[drvid: %1, uid: %2]").arg(1).arg(2);
 
     isInAuth = true;
+    dup_fd = -1;
 
     QDBusPendingCall call = proxy->Identify(device->id, uid);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished,
             this, &BiometricAuthWidget::onIdentifyComplete);
 
-    updateImage(1);
 }
 
 void BiometricAuthWidget::stopAuth()
@@ -117,6 +137,7 @@ void BiometricAuthWidget::stopAuth()
     {
         return;
     }
+
     proxy->StopOps(device->id);
     if(retrytimer&&retrytimer->isActive()){
         retrytimer->stop();
@@ -149,6 +170,10 @@ void BiometricAuthWidget::onIdentifyComplete(QDBusPendingCallWatcher *watcher)
     // 特征识别不匹配
     else if(result == DBUS_RESULT_NOTMATCH)
     {
+        if(usebind){
+            Q_EMIT authComplete(false);
+            return;
+        }
         qDebug() << "Identify failed";
         failedCount++;
         if(failedCount >= GetMaxFailedAutoRetry(userName))
@@ -172,6 +197,10 @@ void BiometricAuthWidget::onIdentifyComplete(QDBusPendingCallWatcher *watcher)
     //识别发生错误
     else if(result == DBUS_RESULT_ERROR)
     {
+        if(usebind){
+            Q_EMIT authComplete(false);
+            return;
+        }
         StatusReslut ret = proxy->UpdateStatus(device->id);
         //识别操作超时
         if(ret.result == 0 && ret.opsStatus == IDENTIFY_TIMEOUT)
@@ -190,11 +219,44 @@ void BiometricAuthWidget::onIdentifyComplete(QDBusPendingCallWatcher *watcher)
                     }
                 });
             }
-        }
+        }else{
+	    Q_EMIT authComplete(false);
+	}
+    }else{
+        Q_EMIT authComplete(false);
     }
     updateImage(0);
 }
 
+void BiometricAuthWidget::onFrameWritten(int drvid)
+{
+
+    if(dup_fd == -1){
+        dup_fd = get_server_gvariant_stdout(drvid);
+    }
+
+    if(dup_fd <= 0)
+        return ;
+
+    cv::Mat img;
+    lseek(dup_fd, 0, SEEK_SET);
+    char base64_bufferData[1024*1024];
+    int rc = read(dup_fd, base64_bufferData, 1024*1024);
+    printf("rc = %d\n", rc);
+
+    cv::Mat mat2(1, sizeof(base64_bufferData), CV_8U, base64_bufferData);
+    img = cv::imdecode(mat2, cv::IMREAD_COLOR);
+    cv::cvtColor(img,img,cv::COLOR_BGR2RGB);
+
+    QImage srcQImage = QImage((uchar*)(img.data), img.cols, img.rows, QImage::Format_RGB888);
+    lblImage->setFixedSize(160,160);
+    lblImage->setGeometry((width() - lblImage->width()) / 2,
+                           lblDevice->geometry().bottom() + 10,
+                           lblImage->width(), lblImage->height());
+    lblImage->setPixmap(QPixmap::fromImage(srcQImage).scaled(lblImage->size()));
+
+}
+
 void BiometricAuthWidget::onStatusChanged(int drvid, int status)
 {
     if(!isInAuth)
@@ -217,6 +279,9 @@ void BiometricAuthWidget::onStatusChanged(int drvid, int status)
 static int count = 0;
 void BiometricAuthWidget::updateImage(int type)
 {
+    if(device->deviceType == DeviceType::Type::Face)
+        return ;
+
     if(type == 0)
     {
         if(movieTimer && movieTimer->isActive())
@@ -261,5 +326,19 @@ void BiometricAuthWidget::setImage(const QString &path)
     QPixmap image(path);
     image = image.scaled(lblImage->width(), lblImage->height(),
                          Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+
     lblImage->setPixmap(image);
 }
+
+bool BiometricAuthWidget::getAuthDouble()
+{
+    QSettings settings("/etc/biometric-auth/ukui-biometric.conf", QSettings::IniFormat);
+    bool distribId = settings.value("DoubleAuth").toBool();
+    return distribId;
+}
+
+void BiometricAuthWidget::setMinImage(float val)
+{
+    resize(400,100+100*val);
+    lblImage->setFixedSize(100*val, 100*val);
+}
