@@ -37,6 +37,8 @@
 #define KEY_BACKGROUND "background"
 #define XSCREENSAVER_DIRNAME "/usr/lib/xscreensaver"
 
+Configuration* Configuration::instance_ = nullptr;
+
 Configuration::Configuration(QObject *parent) : QObject(parent)
 {
 	/* QGSettings for screensaver */
@@ -90,6 +92,13 @@ Configuration::Configuration(QObject *parent) : QObject(parent)
         mode ="image";
 }
 
+Configuration* Configuration::instance(QObject *parent)
+{
+    if(instance_ == nullptr)
+        instance_ = new Configuration(parent);
+    return instance_;
+}
+
 /* Update member value when GSettings changed */
 void Configuration::onConfigurationChanged(QString key)
 {
@@ -115,7 +124,7 @@ void Configuration::onConfigurationChanged(QString key)
 /* Get the executable path of xscreensaver */
 ScreenSaver *Configuration::getScreensaver()
 {
-    QStringList modeStr{"blank-only", "random", "single", "image","default-ukui"};
+    QStringList modeStr{"blank-only", "random", "single", "image","default-ukui","default-ukui-custom"};
     ScreenSaver *saver = new ScreenSaver;
     int index = modeStr.indexOf(mode);
     saver->mode = SaverMode(index);
@@ -141,6 +150,10 @@ ScreenSaver *Configuration::getScreensaver()
         break;
     }
     case SAVER_SINGLE:
+        if(themes.count()==0){
+            saver->path = "/usr/lib/ukui-screensaver/ukui-screensaver-default";
+            break;
+        }
         saver->path = getXScreensaverPath(themes[0]);
         break;
     case SAVER_IMAGE:
@@ -156,7 +169,10 @@ ScreenSaver *Configuration::getScreensaver()
         saver->path = QDir::homePath() + "/" + QStandardPaths::displayName(QStandardPaths::PicturesLocation);
         break;
     }
-    case SAVER_DEFAULE:
+    case SAVER_DEFAULT:
+        saver->path = "/usr/lib/ukui-screensaver/ukui-screensaver-default";
+        break;
+    case SAVER_DEFAULT_CUSTOM:
         saver->path = "/usr/lib/ukui-screensaver/ukui-screensaver-default";
         break;
     default:
@@ -182,14 +198,8 @@ QString Configuration::getBackground()
 {
     if(ispicture(background))
         return background;
-    else if(getSystemDistrib().contains("Ubuntu",Qt::CaseInsensitive))
-        return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
-    else if(getSystemVersion().contains("V10.1",Qt::CaseInsensitive))
-        return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
-    else if(getSystemVersion().contains("V10",Qt::CaseInsensitive))
-        return "/usr/share/backgrounds/kylin/kylin-background.png";
-    else
-        return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
+    
+    return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
 }
 
 bool Configuration::xscreensaverActivatedWhenIdle()
